pusher_beams_web library
Classes
- PusherBeams
-
A web implementation for
PusherBeamsPlatformplugin. This is designed to be a singleton and must be consumed with PusherBeams.instance.
Constants
- uuid → const Uuid
PusherBeamsPlatform plugin.
This is designed to be a singleton and must be consumed with PusherBeams.instance.